==> markdown-doctest-0.6.0.tgz: package/lib/doctest.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _babelPresetEs = require('babel-preset-es2015');

var _babelPresetEs2 = _interopRequireDefault(_babelPresetEs);

var _babelPresetStage = require('babel-preset-stage-0');

var _babelPresetStage2 = _interopRequireDefault(_babelPresetStage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var fs = require('fs');
var vm = require('vm');
var babel = require('babel-core');

var chalk = require('chalk');

var parseCodeSnippets = require('./parse-code-snippets-from-markdown');

function runTests(files, config) {
  var results = files.map(read).map(parseCodeSnippets).map(testFile(config));

  return flattenArray(results);
}

function read(fileName) {
  return { contents: fs.readFileSync(fileName, 'utf8'), fileName: fileName };
}

function makeTestSandbox(config) {
  function sandboxRequire(moduleName) {
    for (var regexRequire in config.regexRequire) {
      var regex = new RegExp(regexRequire);

      var match = regex.exec(moduleName);
      var handler = config.regexRequire[regexRequire];

      if (match) {
        return handler.apply(undefined, _toConsumableArray(match));
      }
    }

    if (config.require[moduleName] === undefined) {
      throw moduleNotFoundError(moduleName);
    }

    return config.require[moduleName];
  }

  var sandboxConsole = {
    log: function log() {
      return null;
    }
  };

  var sandboxGlobals = { require: sandboxRequire, console: sandboxConsole };
  var sandbox = _extends({}, sandboxGlobals, config.globals);

  return sandbox;
}

function testFile(config, shareCodeInFile) {
  return function testFileWithConfig(args) {
    var codeSnippets = args.codeSnippets;
    var fileName = args.fileName;
    var shareCodeInFile = args.shareCodeInFile;

    var results = undefined;

    if (shareCodeInFile) {
      var sandbox = makeTestSandbox(config);
      results = codeSnippets.map(test(config, fileName, sandbox));
    } else {
      results = codeSnippets.map(test(config, fileName));
    }

    return flattenArray(results);
  };
}

function test(config, filename, sandbox) {
  return function (codeSnippet) {
    if (codeSnippet.skip) {
      return { status: 'skip', codeSnippet: codeSnippet, stack: '' };
    }

    var success = false;
    var stack = '';

    var babelOptions = {
      presets: [_babelPresetEs2.default]
    };

    if (config.babel && 'stage' in config.babel && config.babel.stage === 0) {
      babelOptions.presets.push(_babelPresetStage2.default);
    }

    var code = codeSnippet.code;
    var perSnippetSandbox = undefined;

    if (sandbox === undefined) {
      perSnippetSandbox = makeTestSandbox(config);
    }

    if (config.beforeEach) {
      config.beforeEach();
    }

    try {
      if (config.babel !== false) {
        code = babel.transform(codeSnippet.code, babelOptions).code;
      }

      vm.runInNewContext(code, perSnippetSandbox || sandbox);

      success = true;
    } catch (e) {
      stack = e.stack || '';
    }

    var status = success ? 'pass' : 'fail';

    process.stdout.write(success ? chalk.green('.') : chalk.red('x'));

    return { status: status, codeSnippet: codeSnippet, stack: stack };
  };
}

function flattenArray(array) {
  return array.reduce(function (a, b) {
    return a.concat(b);
  }, []);
}

function printResults(results) {
  results.filter(function (result) {
    return result.status === 'fail';
  }).forEach(printFailure);

  var passingCount = results.filter(function (result) {
    return result.status === 'pass';
  }).length;
  var failingCount = results.filter(function (result) {
    return result.status === 'fail';
  }).length;
  var skippingCount = results.filter(function (result) {
    return result.status === 'skip';
  }).length;

  function successfulRun() {
    return failingCount === 0;
  }

  console.log(chalk.green('Passed: ' + passingCount));

  if (skippingCount > 0) {
    console.log(chalk.yellow('Skipped: ' + skippingCount));
  }

  if (successfulRun()) {
    console.log(chalk.green('\nSuccess!'));
  } else {
    console.log(chalk.red('Failed: ' + failingCount));
  }
}

function printFailure(result) {
  console.log(chalk.red('Failed - ' + markDownErrorLocation(result)));
  console.log(relevantStackDetails(result.stack));
}

function relevantStackDetails(stack) {
  var match = stack.match(/([\w\W]*?)at eval/) || stack.match(/([\w\W]*)at [\w*\/]*?doctest.js/);

  if (match !== null) {
    return match[1];
  }

  return stack;
}

function moduleNotFoundError(moduleName) {
  return new Error('\nAttempted to require \'' + chalk.blue(moduleName) + '\' but was not found in config.\nYou need to include it in the require section of your ' + chalk.blue('.markdown-doctest-setup.js') + ' file.\n\nmodule.exports = {\n  require: {\n    ' + chalk.blue('\'' + moduleName + '\': require(\'' + moduleName + '\')') + '\n  }\n}\n  ');
}

function markDownErrorLocation(result) {
  var match = result.stack.match(/eval.*<.*>:(\d+):(\d+)/);

  if (match) {
    var mdLineNumber = parseInt(match[1], 10);
    var columnNumber = parseInt(match[2], 10);

    var lineNumber = result.codeSnippet.lineNumber + mdLineNumber;

    return result.codeSnippet.fileName + ':' + lineNumber + ':' + columnNumber;
  }

  return result.codeSnippet.fileName + ':' + result.codeSnippet.lineNumber;
}

module.exports = { printResults: printResults, runTests: runTests };

==> markdown-doctest-0.7.0.tgz: package/lib/doctest.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _babelPresetEs = require('babel-preset-es2015');

var _babelPresetEs2 = _interopRequireDefault(_babelPresetEs);

var _babelPresetStage = require('babel-preset-stage-0');

var _babelPresetStage2 = _interopRequireDefault(_babelPresetStage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var fs = require('fs');
var vm = require('vm');
var babel = require('babel-core');


var chalk = require('chalk');

var parseCodeSnippets = require('./parse-code-snippets-from-markdown');

function runTests(files, config) {
  var results = files.map(read).map(parseCodeSnippets).map(testFile(config));

  return flattenArray(results);
}

function read(fileName) {
  return { contents: fs.readFileSync(fileName, 'utf8'), fileName: fileName };
}

function makeTestSandbox(config) {
  function sandboxRequire(moduleName) {
    for (var regexRequire in config.regexRequire) {
      var regex = new RegExp(regexRequire);

      var match = regex.exec(moduleName);
      var handler = config.regexRequire[regexRequire];

      if (match) {
        return handler.apply(undefined, _toConsumableArray(match));
      }
    }

    if (config.require[moduleName] === undefined) {
      throw moduleNotFoundError(moduleName);
    }

    return config.require[moduleName];
  }

  var sandboxConsole = {
    log: function log() {
      return null;
    }
  };

  var sandboxGlobals = { require: sandboxRequire, console: sandboxConsole };
  var sandbox = _extends({}, sandboxGlobals, config.globals);

  return sandbox;
}

function testFile(config, shareCodeInFile) {
  return function testFileWithConfig(args) {
    var codeSnippets = args.codeSnippets;
    var fileName = args.fileName;
    var shareCodeInFile = args.shareCodeInFile;

    var results = void 0;

    if (shareCodeInFile) {
      var sandbox = makeTestSandbox(config);
      results = codeSnippets.map(test(config, fileName, sandbox));
    } else {
      results = codeSnippets.map(test(config, fileName));
    }

    return flattenArray(results);
  };
}

function test(config, filename, sandbox) {
  return function (codeSnippet) {
    if (codeSnippet.skip) {
      return { status: 'skip', codeSnippet: codeSnippet, stack: '' };
    }

    var success = false;
    var stack = '';

    var babelOptions = {
      presets: [_babelPresetEs2.default]
    };

    if (config.babel && 'stage' in config.babel && config.babel.stage === 0) {
      babelOptions.presets.push(_babelPresetStage2.default);
    }

    var code = codeSnippet.code;
    var perSnippetSandbox = void 0;

    if (sandbox === undefined) {
      perSnippetSandbox = makeTestSandbox(config);
    }

    if (config.beforeEach) {
      config.beforeEach();
    }

    try {
      if (config.babel !== false) {
        code = babel.transform(codeSnippet.code, babelOptions).code;
      }

      vm.runInNewContext(code, perSnippetSandbox || sandbox);

      success = true;
    } catch (e) {
      stack = e.stack || '';
    }

    var status = success ? 'pass' : 'fail';

    process.stdout.write(success ? chalk.green('.') : chalk.red('x'));

    return { status: status, codeSnippet: codeSnippet, stack: stack };
  };
}

function flattenArray(array) {
  return array.reduce(function (a, b) {
    return a.concat(b);
  }, []);
}

function printResults(results) {
  results.filter(function (result) {
    return result.status === 'fail';
  }).forEach(printFailure);

  var passingCount = results.filter(function (result) {
    return result.status === 'pass';
  }).length;
  var failingCount = results.filter(function (result) {
    return result.status === 'fail';
  }).length;
  var skippingCount = results.filter(function (result) {
    return result.status === 'skip';
  }).length;

  function successfulRun() {
    return failingCount === 0;
  }

  console.log(chalk.green('Passed: ' + passingCount));

  if (skippingCount > 0) {
    console.log(chalk.yellow('Skipped: ' + skippingCount));
  }

  if (successfulRun()) {
    console.log(chalk.green('\nSuccess!'));
  } else {
    console.log(chalk.red('Failed: ' + failingCount));
  }
}

function printFailure(result) {
  console.log(chalk.red('Failed - ' + markDownErrorLocation(result)));
  console.log(relevantStackDetails(result.stack));
}

function relevantStackDetails(stack) {
  var match = stack.match(/([\w\W]*?)at eval/) || stack.match(/([\w\W]*)at [\w*\/]*?doctest.js/);

  if (match !== null) {
    return match[1];
  }

  return stack;
}

function moduleNotFoundError(moduleName) {
  return new Error('\nAttempted to require \'' + chalk.blue(moduleName) + '\' but was not found in config.\nYou need to include it in the require section of your ' + chalk.blue('.markdown-doctest-setup.js') + ' file.\n\nmodule.exports = {\n  require: {\n    ' + chalk.blue('\'' + moduleName + '\': require(\'' + moduleName + '\')') + '\n  }\n}\n  ');
}

function markDownErrorLocation(result) {
  var match = result.stack.match(/eval.*<.*>:(\d+):(\d+)/);

  if (match) {
    var mdLineNumber = parseInt(match[1], 10);
    var columnNumber = parseInt(match[2], 10);

    var lineNumber = result.codeSnippet.lineNumber + mdLineNumber;

    return result.codeSnippet.fileName + ':' + lineNumber + ':' + columnNumber;
  }

  return result.codeSnippet.fileName + ':' + result.codeSnippet.lineNumber;
}

module.exports = { printResults: printResults, runTests: runTests };
